@@ -79,13 +79,11 @@ sub __bernfrac__ {
 
     for (my $i = 0 ; $primes[$i] <= $bound ; ++$i) {        # primes <= bound
         Math::GMPz::Rmpz_ui_pow_ui($u, $primes[$i], $n);    # u = p^n
-        Math::GMPz::Rmpz_sub_ui($u, $u, 1);                 # u = u-1
         Math::MPFR::Rmpfr_mul_z($z, $z, $u, $round);        # z = z*u
-        Math::GMPz::Rmpz_add_ui($u, $u, 1);                 # u = u+1
+        Math::GMPz::Rmpz_sub_ui($u, $u, 1);                 # u = u-1
         Math::MPFR::Rmpfr_div_z($z, $z, $u, $round);        # z = z/u
     }
 
-    Math::MPFR::Rmpfr_ui_div($z, 1, $z, $round);            # z = 1 / z
     Math::MPFR::Rmpfr_mul($z, $z, $K, $round);              # z = z * K
     Math::MPFR::Rmpfr_mul_z($z, $z, $d, $round);            # z = z * d
     Math::MPFR::Rmpfr_ceil($z, $z);                         # z = ceil(z)
